/*
* A grid of random lines.
*
* Copyright (C) 2003, David Redick
* Released under the GNU General Public License (v2)
*/

#include "map.h"
#include "cut.h"


void
lines ()
{
  clear_invert_map ();
  cut ();
  return;
}
